@@ -1,11 +1,12 @@
-from ..util import config,client,oss_client
+from ..util import config,client,oss_client,util
 from terminal import green,bold,yellow
 from .. import const
-from ..util import it
 from ..const import CMD
 
-def all(region=None, osspath=None, locale=None, image=None, type=None, version=None,god=None):
-    if not region and not osspath and not locale and not image and not type and not version and not god:
+FALSE_ARR = ['', 'null', 'None', 'false', 'False']
+
+def all(region=None, osspath=None, locale=None, image=None, type=None, version=None, ssl=None, god=None):
+    if not region and not osspath and not locale and not image and not type and not version and not ssl and not god:
         show_config()
     else:
         if region:
@@ -20,6 +21,8 @@ def all(region=None, osspath=None, locale=None, image=None, type=None, version=N
             update_type(type)
         if version:
             update_version(version)
+        if ssl:
+            update_ssl(ssl)
         if god:
             update_god(god)
         print(green('done'))
@@ -31,17 +34,22 @@ def update_region(region):
     try:
         client.check_client(m)
         config.setConfigs(config.COMMON, m)
+
+        util.set_default_type_n_image()
+
     except Exception as e:
         e = '%s' % e
         if 'nodename nor servname provided' in e:
-            raise Exception('Invalid region %s' % region)
+            raise Exception('Invalid region %s\n %s' % (region,e))
         else:
             raise Exception(e)
 
 
 
+
+
 def update_osspath(osspath):
-    if osspath in ['', 'null', 'None', 'false', 'False']:
+    if osspath in FALSE_ARR:
         # remove
         config.removeConfig(config.COMMON, 'osspath')
     else:
@@ -56,11 +64,11 @@ def update_osspath(osspath):
             config.setConfigs(config.COMMON, m)
 
         except Exception as e:
-            raise Exception('Invalid osspath %s' % (osspath)) if m.get('osspath') else e
+            raise Exception('Invalid osspath %s\n  %s' % (osspath,e)) if m.get('osspath') else e
 
 
 def update_locale(locale):
-    if locale in ['', 'null', 'None', 'false', 'False']:
+    if locale in FALSE_ARR:
         # remove
         config.removeConfig(config.COMMON, 'locale')
     else:
@@ -73,7 +81,7 @@ def update_locale(locale):
 
 def update_image(image):
     image = image.strip()
-    if image in ['','null','None','false','False']:
+    if image in FALSE_ARR:
         # remove
         config.removeConfig(config.COMMON, 'defaultimage')
     else:
@@ -83,19 +91,16 @@ def update_image(image):
 
 def update_type(type):
     type = type.strip()
-    if type in ['','null','None','false','False']:
+    if type in FALSE_ARR:
         # remove
         config.removeConfig(config.COMMON, 'defaulttype')
     else:
         m = config.getConfigs(config.COMMON)
 
-        itMap = {}
-        arr = it.list()
-        for n in arr:
-            itMap[n.get('name')] = 1
+        itMap = client.get_ins_type_map()
 
         if not itMap.get(type):
-            print(yellow("WARNING: '%s' may not be valid, type '%s it' for more" % (type, CMD)))
+            raise Exception("'%s' is invalid, type '%s it' for more" % (type, CMD))
 
         m['defaulttype'] = type
         config.setConfigs(config.COMMON, m)
@@ -107,7 +112,7 @@ def update_version(version):
     m = config.getConfigs(config.COMMON)
 
     version = version.strip()
-    if version in ['', 'null', 'None', 'false', 'False']:
+    if version in FALSE_ARR:
         config.removeConfig(config.COMMON, 'version')
     else:
         m['version'] = version
@@ -118,11 +123,19 @@ def update_version(version):
         except Exception as e:
             raise Exception('Invalid version %s' % version)
 
+def update_ssl(ssl):
+    m = config.getConfigs(config.COMMON)
+    ssl = ssl.strip()
+    if ssl in FALSE_ARR:
+        m['ssl'] = 'false'
+        config.setConfigs(config.COMMON, m)
+    else:
+        config.removeConfig(config.COMMON, 'ssl')
 
 def update_god(god):
     m = config.getConfigs(config.COMMON)
     god = god.strip()
-    if god not in ['', 'null', 'None', 'false', 'False']:
+    if god not in FALSE_ARR:
         m['god'] = '1'
         config.setConfigs(config.COMMON, m)
     else:
@@ -131,7 +144,7 @@ def update_god(god):
 
 def show_config():
     try:
-        arr = ['region','accesskeyid','accesskeysecret','version','osspath','locale', 'defaultimage','defaulttype','god',
+        arr = ['region','accesskeyid','accesskeysecret','version','osspath','locale', 'defaultimage','defaulttype','ssl','god',
                'oss_region','oss_id','oss_key']
         opt = config.getConfigs(config.COMMON, arr)
         if not opt:
